# References
List of references of source materials used or inspired from to built this project:

- [The Hitchhicker's Guide to Python](https://docs.python-guide.org/)
- [keep a changelog](https://keepachangelog.com/en/1.0.0/)
- [Semantinc Versioning](https://semver.org/spec/v2.0.0.html)
- [MkDocs](https://www.mkdocs.org/)
- [Material for MkDocs](https://squidfunk.github.io/mkdocs-material)
- [Icongram](https://icongr.am/devicon)
- [Emojipedia](https://emojipedia.org/)
- [Watchdog](https://github.com/gorakhargosh/watchdog)
